pub struct BoxTree {
root: BlockFormattingContext,
pub(crate) viewport_overflow: AxesOverflow,
}Fields
root: BlockFormattingContextContains typically exactly one block-level box, which was generated by the root element.
There may be zero if that element has display: none.
viewport_overflow: AxesOverflowWhether or not the viewport should be sensitive to scrolling input events in two axes
Implementations
Sourceimpl BoxTree
impl BoxTree
pub(crate) fn construct( context: &LayoutContext<'_>, root_element: ServoLayoutNode<'_>, ) -> Self
fn viewport_overflow( root_element: ServoThreadSafeLayoutNode<'_>, root_box: Option<&ArcRefCell<BlockLevelBox>>, ) -> AxesOverflow
Sourceimpl BoxTree
impl BoxTree
pub(crate) fn layout( &self, layout_context: &LayoutContext<'_>, viewport: UntypedSize2D<Au>, ) -> FragmentTree